
Function Wrappers and Sensitivity Tools
==========================================

Function wrappers
---------------------------
.. autoclass:: paragami.function_patterns.FlattenedFunction
  :members:

.. autoclass:: paragami.function_patterns.Functor
  :members:

.. autoclass:: paragami.optimization_lib.HyperparameterSensitivityLinearApproximation
  :members:

.. autoclass:: paragami.optimization_lib.PreconditionedFunction
  :members:
